@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0505';
 
 use Carp;
 use Game::Battleship::Player;
@@ -175,13 +175,13 @@ Game::Battleship - "You sunk my battleship!"
 
 =head1 VERSION
 
-version 0.0504
+version 0.0505
 
 =head1 SYNOPSIS
 
   use Game::Battleship;
   my $g = Game::Battleship->new(qw( Gene Aaron ));
-  $g->add_player('Alisa');
+  $g->add_player('Tabi');
   my $winner = $g->play();
   print $winner->name(), " wins!\n";
 
