@@ -1,7 +1,6 @@
 package Game::Battleship::Craft;
-$Game::Battleship::Craft::VERSION = '0.0504';
+$Game::Battleship::Craft::VERSION = '0.0505';
 our $AUTHORITY = 'cpan:GENE';
-$VERSION = '0.0302';
 use strict;
 use warnings;
 use Carp;
@@ -55,7 +54,7 @@ Game::Battleship::Craft
 
 =head1 VERSION
 
-version 0.0504
+version 0.0505
 
 =head1 SYNOPSIS
 
@@ -122,16 +121,6 @@ Have different numbers of different weapons.
 
 Allow a craft to have a width.
 
-Allow diagonal positions too.  Why not?
-
-=head1 AUTHOR
-
-Gene Boggs E<lt>gene@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-See L<Game::Battleship>.
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
